<?php
/**
 * Adds Recent posts with thumbnail Widget
 */
if ( ! class_exists( 'Cihuatl_Recent_Posts' ) ) {
	class Cihuatl_Recent_Posts extends WP_Widget {

		/**
		 * Register widget with WordPress.
		 */
		function __construct() {
			parent::__construct(
				'cihuatl_recent_posts', // Base ID
				esc_html__( 'Cihuatl Recent Posts with Thumbnail', 'cihuatl' ), // Name
				array( 'description' => esc_html__( 'Display the latest blog post with thumbnail', 'cihuatl' ) ) // Args
			);
		}

		/**
		 * Front-end display of widget.
		 *
		 * @see WP_Widget::widget()
		 *
		 * @param array $args     Widget arguments.
		 * @param array $instance Saved values from database.
		 */
		public function widget( $args, $instance ) {
			echo $args['before_widget'];
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
			}

			$number_of_posts = ! empty( $instance['number_of_posts'] ) ? intval( $instance['number_of_posts'] ) : 5;

			$wp_query_attributes = array(
				'posts_per_page' => $number_of_posts,
                'ignore_sticky_posts' => true,
			);

			if ( $instance['category'] != 0 ) {
				$wp_query_attributes['category__in'] = array( $instance['category'] );
			}

			$recent_posts = new WP_Query( $wp_query_attributes );

			if ( $recent_posts->have_posts() ) {
				while ( $recent_posts->have_posts() ) {
					$recent_posts->the_post();
					?>
				<a href="<?php the_permalink(); ?>">
					<div class="popular-thumbnail">
						<?php the_post_thumbnail( 'thumbnail' ); ?>
					</div>
					<div class="info">
						<div class="popular-post-title"><?php the_title(); ?></div>
						<?php if ( ! empty( $instance['show_excerpt'] ) ) { ?>
						<div class="popular-post-description"><?php the_excerpt(); ?></div>
						<?php } ?>
					</div>
				</a>
					<?php
				}
			}
			echo $args['after_widget'];
		}

		/**
		 * Back-end widget form.
		 *
		 * @see WP_Widget::form()
		 *
		 * @param array $instance Previously saved values from database.
		 */
		public function form( $instance ) {
			$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'Recent Posts', 'cihuatl' );

			$number_of_posts = ! empty( $instance['number_of_posts'] ) ? intval( $instance['number_of_posts'] ) : 5;

			$category = ! empty( $instance['category'] ) ? intval( $instance['category'] ) : 0;

			$categories    = cihuatl_get_all_categories();
			$categories[0] = __( 'Any category', 'cihuatl' );

			$show_excerpt = ( ! empty( $instance['show_excerpt'] ) ) ? ' checked="checked" ' : '';
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'cihuatl' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'number_of_posts' ) ); ?>"><?php esc_html_e( 'Number of posts to be displayed:', 'cihuatl' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_of_posts' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_of_posts' ) ); ?>" type="text" value="<?php echo esc_attr( $number_of_posts ); ?>">
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php esc_html_e( 'Only posts inside this category (optional):', 'cihuatl' ); ?></label>
				<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'category' ) ); ?>">
					<?php
					foreach ( $categories as $id => $cat ) {
						?>
					<option value="<?php echo $id; ?>" <?php echo ( $id == $category ) ? ' selected="selected"' : ''; ?>><?php echo $cat; ?></option>
						<?php
					}
					?>
				</select>
			</p>
			<p>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'show_excerpt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_excerpt' ) ); ?>" <?php echo $show_excerpt; ?> type="checkbox" >
				<label for="<?php echo esc_attr( $this->get_field_id( 'show_excerpt' ) ); ?>"><?php esc_html_e( 'Display post excerpt.', 'cihuatl' ); ?></label>
			</p>
			<?php
		}

		/**
		 * Sanitize widget form values as they are saved.
		 *
		 * @see WP_Widget::update()
		 *
		 * @param array $new_instance Values just sent to be saved.
		 * @param array $old_instance Previously saved values from database.
		 *
		 * @return array Updated safe values to be saved.
		 */
		public function update( $new_instance, $old_instance ) {
			$instance          = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';

			$instance['number_of_posts'] = ( ! empty( $new_instance['number_of_posts'] ) ) ? intval( $new_instance['number_of_posts'] ) : 5;

			$instance['category'] = ( ! empty( $new_instance['category'] ) ) ? intval( $new_instance['category'] ) : 0;

			$instance['show_excerpt'] = ( ! empty( $new_instance['show_excerpt'] ) ) ? 1 : 0;

			return $instance;
		}

	} // class Cihuatl_Recent_Posts
}

// register Cihuatl_Recent_Posts widget
function register_recent_posts_widget() {
	register_widget( 'Cihuatl_Recent_Posts' );
}
add_action( 'widgets_init', 'register_recent_posts_widget' );
