<?php
/**
 * Cihuatl functions and definitions
 *
 * @package WordPress
 * @subpackage Cihuatl
 * @since 1.0.0
 */

/**
 * Table of Contents:
 * Theme Support
 * Required Files
 * Register Styles
 * Register Scripts
 * Register Menus
 * Custom Logo
 * WP Body Open
 * Register Sidebars
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function cihuatl_theme_support() {

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Custom background color.
	add_theme_support(
		'custom-background',
		array(
			'default-color' => 'fff',
		)
	);

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// Set post thumbnail size.
	set_post_thumbnail_size( 1200, 9999 );

	// Add custom image size used in Cover Template.
	add_image_size( 'cihuatl-fullscreen', 1980, 9999 );

	// Custom logo.
	$logo_width  = 120;
	$logo_height = 90;

	// If the retina setting is active, double the recommended width and height.
	if ( get_theme_mod( 'retina_logo', false ) ) {
		$logo_width  = floor( $logo_width * 2 );
		$logo_height = floor( $logo_height * 2 );
	}

	add_theme_support(
		'custom-logo',
		array(
			'height'      => $logo_height,
			'width'       => $logo_width,
			'flex-height' => true,
			'flex-width'  => true,
		)
	);

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'script',
			'style',
		)
	);

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Cihuatl, use a find and replace
	 * to change 'cihuatl' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'cihuatl' );

	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

}

add_action( 'after_setup_theme', 'cihuatl_theme_support' );

/**
 * REQUIRED FILES
 * Include required files.
 */
require get_template_directory() . '/inc/template-tags.php';

// Handle Customizer settings.
require get_template_directory() . '/classes/class-cihuatl-customize.php';

// Handle Menu walker
require get_template_directory() . '/classes/class-cihuatl-walker-menu.php';

// Handle Comments walker
require get_template_directory() . '/classes/class-cihuatl-walker-comment.php';

// Require Separator Control class.
require get_template_directory() . '/classes/class-cihuatl-separator-control.php';

// Require Recent Posts with Thumbnail class widget
require get_template_directory() . '/classes/class-cihuatl-posts-widget.php';

// Require Recent Comments with avatar class widget
require get_template_directory() . '/classes/class-cihuatl-comments-widget.php';

// Custom CSS.
require get_template_directory() . '/inc/custom-css.php';

/**
 * Register and Enqueue Styles.
 */
function cihuatl_register_styles() {

	$theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_style( 'cihuatl-bootstrapp', get_stylesheet_directory_uri() . '/css/bootstrap.min.css', array(), $theme_version );
	wp_enqueue_style( 'cihuatl-fonts', get_stylesheet_directory_uri() . '/css/fonts.css', array(), $theme_version );
	wp_enqueue_style( 'cihuatl-font-awesome', get_stylesheet_directory_uri() . '/css/font-awesome.min.css', array(), $theme_version );
	wp_enqueue_style( 'cihuatl-style', get_stylesheet_uri(), array(), $theme_version );
	wp_style_add_data( 'cihuatl-style', 'rtl', 'replace' );

	// Add output of Customizer settings as inline style.
	wp_add_inline_style( 'cihuatl-style', cihuatl_get_customizer_css() );
}

add_action( 'wp_enqueue_scripts', 'cihuatl_register_styles' );

/**
 * Register and Enqueue Scripts.
 */
function cihuatl_register_scripts() {

	$theme_version = wp_get_theme()->get( 'Version' );

	if ( ( ! is_admin() ) && is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'cihuatl-bootstrap-js', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'cihuatl-js', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), $theme_version, true );
	wp_script_add_data( 'cihuatl-js', 'async', true );

}

add_action( 'wp_enqueue_scripts', 'cihuatl_register_scripts' );

/**
 * Enqueues scripts for customizer controls & settings.
 *
 * @since Cihuatl 1.0
 *
 * @return void
 */
function cihuatl_customize_controls_enqueue_scripts() {
	$theme_version = wp_get_theme()->get( 'Version' );

	// Add main customizer js file.
	wp_enqueue_script( 'cihuatl-customize', get_template_directory_uri() . '/js/customize.js', array( 'jquery', 'customize-controls' ), $theme_version, true );

}

add_action( 'customize_controls_enqueue_scripts', 'cihuatl_customize_controls_enqueue_scripts' );

/**
 * Enqueue scripts for the customizer preview.
 *
 * @since Cihuatl 1.0
 *
 * @return void
 */
function cihuatl_customize_preview_init() {
	$theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script( 'cihuatl-customize-preview', get_theme_file_uri( '/js/customize-preview.js' ), array( 'customize-preview', 'customize-selective-refresh', 'jquery' ), $theme_version, true );
}

add_action( 'customize_preview_init', 'cihuatl_customize_preview_init' );

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function cihuatl_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- assets/js/skip-link-focus-fix.js`.
	?>
	<script>
		/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'cihuatl_skip_link_focus_fix' );


/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function cihuatl_menus() {

	$locations = array(
		'primary' => __( 'Top Menu', 'cihuatl' ),
	);

	register_nav_menus( $locations );
}

add_action( 'init', 'cihuatl_menus' );

/**
 * Get the information about the logo.
 *
 * @param string $html The HTML output from get_custom_logo (core function).
 *
 * @return string $html
 */
function cihuatl_get_custom_logo( $html ) {

	$logo_id = get_theme_mod( 'custom_logo' );

	if ( ! $logo_id ) {
		return $html;
	}

	$logo = wp_get_attachment_image_src( $logo_id, 'full' );

	if ( $logo ) {
		// For clarity.
		$logo_width  = esc_attr( $logo[1] );
		$logo_height = esc_attr( $logo[2] );

		// If the retina logo setting is active, reduce the width/height by half.
		if ( get_theme_mod( 'retina_logo', false ) ) {
			$logo_width  = floor( $logo_width / 2 );
			$logo_height = floor( $logo_height / 2 );

			$search = array(
				'/width=\"\d+\"/iU',
				'/height=\"\d+\"/iU',
			);

			$replace = array(
				"width=\"{$logo_width}\"",
				"height=\"{$logo_height}\"",
			);

			// Add a style attribute with the height, or append the height to the style attribute if the style attribute already exists.
			if ( strpos( $html, ' style=' ) === false ) {
				$search[]  = '/(src=)/';
				$replace[] = "style=\"height: {$logo_height}px;\" src=";
			} else {
				$search[]  = '/(style="[^"]*)/';
				$replace[] = "$1 height: {$logo_height}px;";
			}

			$html = preg_replace( $search, $replace, $html );

		}
	}

	return $html;

}

add_filter( 'get_custom_logo', 'cihuatl_get_custom_logo' );

if ( ! function_exists( 'wp_body_open' ) ) {

	/**
	 * Shim for wp_body_open, ensuring backwards compatibility with versions of WordPress older than 5.2.
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
}

/**
 * Include a skip to content link at the top of the page so that users can bypass the menu.
 */
function cihuatl_skip_link() {
	echo '<a class="skip-link screen-reader-text" href="#site-content">' . __( 'Skip to the content', 'cihuatl' ) . '</a>';
}

add_action( 'wp_body_open', 'cihuatl_skip_link', 5 );

/**
 * Register widget areas.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function cihuatl_sidebar_registration() {

	// Arguments used in all register_sidebar() calls.
	$shared_args = array(
		'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
		'after_title'   => '</h2>',
		'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
		'after_widget'  => '</div></div>',
	);

	// Right sidebar
	register_sidebar(
		array_merge(
			$shared_args,
			array(
				'name'        => __( 'Right Sidebar', 'cihuatl' ),
				'id'          => 'right-sidebar',
				'description' => __( 'Widgets in this area will be displayed in the right column.', 'cihuatl' ),
			)
		)
	);

	// Footer #1.
	register_sidebar(
		array_merge(
			$shared_args,
			array(
				'name'        => __( 'Footer #1', 'cihuatl' ),
				'id'          => 'sidebar-1',
				'description' => __( 'Widgets in this area will be displayed in the first column in the footer.', 'cihuatl' ),
			)
		)
	);

	// Footer #2.
	register_sidebar(
		array_merge(
			$shared_args,
			array(
				'name'        => __( 'Footer #2', 'cihuatl' ),
				'id'          => 'sidebar-2',
				'description' => __( 'Widgets in this area will be displayed in the second column in the footer.', 'cihuatl' ),
			)
		)
	);

	// Footer #3.
	register_sidebar(
		array_merge(
			$shared_args,
			array(
				'name'        => __( 'Footer #3', 'cihuatl' ),
				'id'          => 'sidebar-3',
				'description' => __( 'Widgets in this area will be displayed in the third column in the footer.', 'cihuatl' ),
			)
		)
	);

}
add_action( 'widgets_init', 'cihuatl_sidebar_registration' );

/**
 * Overwrite default more tag with styling and screen reader markup.
 *
 * @param string $html The default output HTML for the more tag.
 *
 * @return string $html
 */
function cihuatl_read_more_tag( $html ) {
	return preg_replace( '/<a(.*)>(.*)<\/a>/iU', sprintf( '<div class="read-more-button-wrap"><a$1><span class="faux-button">$2</span> <span class="screen-reader-text">"%1$s"</span></a></div>', get_the_title( get_the_ID() ) ), $html );
}

add_filter( 'the_content_more_link', 'cihuatl_read_more_tag' );

/**
 * Defining content width
 *
 */
if ( ! isset( $content_width ) ) {
    $content_width = 807;
}

/**
 * Setting default theme mod values
 *
 * @return void
 */
function cihuatl_set_default_theme_mods() {

    set_theme_mod( 'show_slider', true );

}
add_action( 'after_setup_theme', 'cihuatl_set_default_theme_mods' );